@@ -1,7 +1,7 @@
 
 #include	<glib-object.h>
 
-#define G_ENABLE_DEBUG
+
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
 #define g_marshal_value_peek_char(v)     g_value_get_char (v)
@@ -50,10 +50,10 @@
 /* VOID:INT,INT,INT (marshal.list:1) */
 void
 scintilla_marshal_VOID__INT_INT_INT (GClosure     *closure,
-                                     GValue       *return_value,
+                                     GValue       *return_value G_GNUC_UNUSED,
                                      guint         n_param_values,
                                      const GValue *param_values,
-                                     gpointer      invocation_hint,
+                                     gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_INT_INT) (gpointer     data1,
@@ -89,10 +89,10 @@ scintilla_marshal_VOID__INT_INT_INT (GClosure     *closure,
 /* VOID:INT,ULONG,LONG (marshal.list:2) */
 void
 scintilla_marshal_VOID__INT_ULONG_LONG (GClosure     *closure,
-                                        GValue       *return_value,
+                                        GValue       *return_value G_GNUC_UNUSED,
                                         guint         n_param_values,
                                         const GValue *param_values,
-                                        gpointer      invocation_hint,
+                                        gpointer      invocation_hint G_GNUC_UNUSED,
                                         gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_ULONG_LONG) (gpointer     data1,
@@ -128,10 +128,10 @@ scintilla_marshal_VOID__INT_ULONG_LONG (GClosure     *closure,
 /* VOID:INT,INT (marshal.list:3) */
 void
 scintilla_marshal_VOID__INT_INT (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
@@ -165,10 +165,10 @@ scintilla_marshal_VOID__INT_INT (GClosure     *closure,
 /* VOID:INT,INT,STRING,INT,INT,INT,INT,INT (marshal.list:4) */
 void
 scintilla_marshal_VOID__INT_INT_STRING_INT_INT_INT_INT_INT (GClosure     *closure,
-                                                            GValue       *return_value,
+                                                            GValue       *return_value G_GNUC_UNUSED,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
-                                                            gpointer      invocation_hint,
+                                                            gpointer      invocation_hint G_GNUC_UNUSED,
                                                             gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_INT_STRING_INT_INT_INT_INT_INT) (gpointer     data1,
@@ -211,3 +211,40 @@ scintilla_marshal_VOID__INT_INT_STRING_INT_INT_INT_INT_INT (GClosure     *closur
             data2);
 }
 
+/* VOID:INT,STRING (marshal.list:5) */
+void
+scintilla_marshal_VOID__INT_STRING (GClosure     *closure,
+                                    GValue       *return_value G_GNUC_UNUSED,
+                                    guint         n_param_values,
+                                    const GValue *param_values,
+                                    gpointer      invocation_hint G_GNUC_UNUSED,
+                                    gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__INT_STRING) (gpointer     data1,
+                                                 gint         arg_1,
+                                                 gpointer     arg_2,
+                                                 gpointer     data2);
+  register GMarshalFunc_VOID__INT_STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__INT_STRING) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_int (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
+            data2);
+}
+
