@@ -30,19 +30,15 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
-#include <gtkscintilla.h>
 
 #ifdef ENABLE_NLS
 #include <glib/gi18n.h>
-#else							/* ENABLE_NLS */
+#else /* ENABLE_NLS */
 #define _(String)(String)
 #define N_(String)(String)
-#endif							/* ENABLE_NLS */
+#endif /* ENABLE_NLS */
 
 #define GPHPEDIT_PIXMAP_ICON "gphpedit.png"
-
-gboolean add (gpointer bla);
-gint debug(gchar *strMsg, ...);
+#define GPHPEDIT_PIXMAP_FULL_PATH (PIXMAP_DIR "/" GPHPEDIT_PIXMAP_ICON)
 
 #endif
